This is a statement by Frank Wiles
that grants permission to relicense its copyrights in the Python ZeroMQ bindings
(pyzmq) under the Mozilla Public License v2 (MPLv2) or any other
Open Source Initiative approved license chosen by the current PyZMQ
BDFL (Benevolent Dictator for Life).

A portion of the commits made by the GitHub handle "frankwiles", with
commit author "Frank Wiles <frank@revsys.com>", are copyright of Frank Wiles .
This document hereby grants the libzmq project team to relicense pyzmq,
including all past, present and future contributions of the author listed above.

Frank Wiles
2017/07/17
